RbumCertModifyReq

Struct RbumCertModifyReq 

pub struct RbumCertModifyReq {
    pub ak: Option<TrimString>,
    pub sk: Option<TrimString>,
    pub sk_invisible: Option<bool>,
    pub ignore_check_sk: bool,
    pub ext: Option<String>,
    pub start_time: Option<DateTime<Utc>>,
    pub end_time: Option<DateTime<Utc>>,
    pub conn_uri: Option<String>,
    pub status: Option<RbumCertStatusKind>,
}
Modify request for certificate

凭证修改请求

Fields

ak: Option<TrimString>sk: Option<TrimString>sk_invisible: Option<bool>

Whether to hide the sk

是否隐藏密钥

In some scenarios with high security requirements, you can choose to hide the key, such as: display as “******”.

在一些安全性要求较高的场景下,可以选择隐藏密钥,如:显示为“******”。

ignore_check_sk: bool

Whether to ignore the key check

是否忽略密钥校验

WARNING: This field is only for special scenarios, please use it with caution.

警告:此字段仅用于特殊场景,请谨慎使用。

ext: Option<String>

Certificate extension information

凭证扩展信息

Such as database connection pool configuration.

比如数据库连接池配置。

Different from crate::rbum::dto::rbum_cert_conf_dto::RbumCertConfModifyReq::ext, this field is used to identify the specific extension information of the certificate.

crate::rbum::dto::rbum_cert_conf_dto::RbumCertConfModifyReq::ext 不同,此字段用于标识该条凭证的特有的扩展信息。

start_time: Option<DateTime<Utc>>

Certificate effective time

凭证的生效时间

end_time: Option<DateTime<Utc>>

Certificate expiration time

凭证的失效时间

conn_uri: Option<String>

Certificate connection address

凭证连接地址

Different from crate::rbum::dto::rbum_cert_conf_dto::RbumCertConfModifyReq::conn_uri, this field is used to identify the specific connection address of the certificate.

crate::rbum::dto::rbum_cert_conf_dto::RbumCertConfModifyReq::conn_uri 不同,此字段用于标识该条凭证的特有的连接地址。

status: Option<RbumCertStatusKind>

Credential status

凭证的状态