RbumKindAddReq

Struct RbumKindAddReq 

pub struct RbumKindAddReq {
    pub module: Option<String>,
    pub code: TrimString,
    pub name: TrimString,
    pub note: Option<String>,
    pub icon: Option<String>,
    pub sort: Option<i64>,
    pub ext_table_name: Option<String>,
    pub scope_level: Option<RbumScopeLevelKind>,
}
Add request for resource kind

资源类型添加请求

Fields

module: Option<String>

Resource kind module

资源类型模块

Default is empty

默认为

Used to further divide the resource kind. For example, there are multiple resource kinds under the cmdb compute module, such as ecs, ec2, k8s.

用于对资源类型做简单的分类。比如 cmdb计算 模块下可以有 ecs、ec2、k8s 等多个资源类型。

code: TrimString

Resource kind code

资源类型编码

Resource kind code, which is required to conform to the scheme specification in the uri, matching the regular: ^[a-z0-9-.]+$ .

资源类型编码,需要符合uri中的scheme规范,匹配正则:^[a-z0-9-.]+$

name: TrimString

Resource kind name

资源类型名称

note: Option<String>

Resource kind note

资源类型备注

icon: Option<String>

Resource kind icon

资源类型图标

sort: Option<i64>

Resource kind sort

资源类型排序

ext_table_name: Option<String>

Extension table name

扩展表名

Each resource kind can specify an extension table for storing customized data.

每个资源类型可以指定一个扩展表用于存储自定义数据。

scope_level: Option<RbumScopeLevelKind>