RbumKindModifyReq

Struct RbumKindModifyReq 

pub struct RbumKindModifyReq {
    pub module: Option<String>,
    pub name: Option<TrimString>,
    pub note: Option<String>,
    pub icon: Option<String>,
    pub sort: Option<i64>,
    pub ext_table_name: Option<String>,
    pub scope_level: Option<RbumScopeLevelKind>,
}
Modify request for resource kind

资源类型修改请求

Fields

module: Option<String>

Resource kind module

资源类型模块

Used to further divide the resource kind. For example, there are multiple resource kinds under the cmdb compute module, such as ecs, ec2, k8s.

用于对资源类型做简单的分类。比如 cmdb计算 模块下可以有 ecs、ec2、k8s 等多个资源类型。

name: Option<TrimString>

Resource kind name

资源类型名称

note: Option<String>

Resource kind note

资源类型备注

icon: Option<String>

Resource kind icon

资源类型图标

sort: Option<i64>

Resource kind sort

资源类型排序

ext_table_name: Option<String>

Extension table name

扩展表名

Each resource kind can specify an extension table for storing customized data.

每个资源类型可以指定一个扩展表用于存储自定义数据。

scope_level: Option<RbumScopeLevelKind>