RbumRelAddReq

Struct RbumRelAddReq 

pub struct RbumRelAddReq {
    pub tag: String,
    pub note: Option<String>,
    pub from_rbum_kind: RbumRelFromKind,
    pub from_rbum_id: String,
    pub to_rbum_item_id: String,
    pub to_own_paths: String,
    pub ext: Option<String>,
    pub to_is_outside: bool,
}
Add request for resource relationship

资源关联添加请求

Fields

tag: String

Relationship tag

关联标签

Used to distinguish different relationships.

用于区分不同的关联关系。

note: Option<String>

Relationship note

关联备注

from_rbum_kind: RbumRelFromKind

Relationship source type

关联来源方的类型

from_rbum_id: String

Relationship source id

关联来源方的id

to_rbum_item_id: String

Relationship target id

关联目标方的id

to_own_paths: String

Relationship target ownership path

关联目标方的所有权路径

ext: Option<String>

Relationship extension information

关联扩展信息

E.g. the record from or to is in another service, to avoid remote calls, you can redundantly add the required information to this field.

例如:记录来源或目标在另一个服务中,为避免远程调用,可以将所需信息冗余添加到此字段。

to_is_outside: bool

Whether the target is an external object

关联目标方是否是外部对象

If true, the validity of the associated target will not be verified.

当为 true 不会校验关联目标方的合法性。