pub struct RbumRelBoneResp {
pub tag: String,
pub note: String,
pub from_rbum_kind: RbumRelFromKind,
pub rel_id: String,
pub rel_name: String,
pub rel_own_paths: String,
pub ext: String,
}Expand description
Resource relationship bone information
资源关联骨干信息
Fields
tag: StringRelationship tag
关联标签
note: StringRelationship note
关联备注
from_rbum_kind: RbumRelFromKindRelationship source type
关联来源方的类型
rel_id: StringRelationship source or target id
关联来源方或目标方的id
rel_name: StringRelationship source or target name
关联来源方或目标方的名称
When from_rbum_kind is crate::rbum::rbum_enumeration::RbumRelFromKind::Item is the name of the resource item,
When from_rbum_kind is crate::rbum::rbum_enumeration::RbumRelFromKind::Set is the name of the resource set,
When from_rbum_kind is crate::rbum::rbum_enumeration::RbumRelFromKind::SetCate is the name of the resource set category(node).
当 from_rbum_kind 为 crate::rbum::rbum_enumeration::RbumRelFromKind::Item 时是资源项的名称,
当 from_rbum_kind 为 crate::rbum::rbum_enumeration::RbumRelFromKind::Set 时是资源集的名称,
当 from_rbum_kind 为 crate::rbum::rbum_enumeration::RbumRelFromKind::SetCate 时是资源集分类(节点)的名称。
rel_own_paths: StringRelationship source or target ownership path
关联来源方或目标方的所有权路径
ext: StringRelationship extension information
关联扩展信息
E.g. the record from or to is in another service, to avoid remote calls, you can redundantly add the required information to this field.
例如:记录来源或目标在另一个服务中,为避免远程调用,可以将所需信息冗余添加到此字段。
Implementations
Sourceimpl RbumRelBoneResp
impl RbumRelBoneResp
Sourcepub fn new(detail: RbumRelDetailResp, package_to_info: bool) -> RbumRelBoneResp
pub fn new(detail: RbumRelDetailResp, package_to_info: bool) -> RbumRelBoneResp
According to the relationship detail information, generate the relationship summary information
根据关联详细信息生成关联概要信息
Arguments
detail- Relationship detail informationpackage_to_info- Iftrue, generate the summary information of the relationship source side, iffalse, generate the summary information of the relationship target side