pub struct RbumRelModifyReq {
pub tag: Option<String>,
pub note: Option<String>,
pub ext: Option<String>,
}Expand description
Modify request for resource relationship
资源关联修改请求
Fields
tag: Option<String>Relationship tag
关联标签
Used to distinguish different relationships.
用于区分不同的关联关系。
note: Option<String>Relationship note
关联备注
ext: Option<String>Relationship extension information
关联扩展信息
E.g. the record from or to is in another service, to avoid remote calls, you can redundantly add the required information to this field.
例如:记录来源或目标在另一个服务中,为避免远程调用,可以将所需信息冗余添加到此字段。