pub struct RbumSetDetailResp {Show 15 fields
pub id: String,
pub code: String,
pub kind: String,
pub name: String,
pub note: String,
pub icon: String,
pub sort: i64,
pub ext: String,
pub own_paths: String,
pub owner: String,
pub owner_name: Option<String>,
pub create_time: DateTime<Utc>,
pub update_time: DateTime<Utc>,
pub scope_level: RbumScopeLevelKind,
pub disabled: bool,
}Expand description
Resource set detail information
资源集详细信息
Fields
id: StringResource set id
资源集id
code: StringResource set code
资源集编码
kind: StringResource set kind
资源集类型
name: StringResource set name
资源集名称
note: StringResource set note
资源集备注
icon: StringResource set icon
资源集图标
sort: i64Resource set sort
资源集排序
ext: StringResource set extension information
资源集扩展信息
own_paths: Stringowner: Stringowner_name: Option<String>create_time: DateTime<Utc>update_time: DateTime<Utc>scope_level: RbumScopeLevelKinddisabled: boolTrait Implementations
Sourceimpl Debug for RbumSetDetailResp
impl Debug for RbumSetDetailResp
Sourceimpl<'de> Deserialize<'de> for RbumSetDetailResp
impl<'de> Deserialize<'de> for RbumSetDetailResp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromQueryResult for RbumSetDetailResp
impl FromQueryResult for RbumSetDetailResp
Sourcefn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
fn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
Instantiate a Model from a QueryResult Read more
Sourcefn from_query_result_nullable(
row: &QueryResult,
pre: &str,
) -> Result<Self, TryGetError>
fn from_query_result_nullable( row: &QueryResult, pre: &str, ) -> Result<Self, TryGetError>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option Read more
Sourcefn from_query_result_optional(
res: &QueryResult,
pre: &str,
) -> Result<Option<Self>, DbErr>
fn from_query_result_optional( res: &QueryResult, pre: &str, ) -> Result<Option<Self>, DbErr>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option
Sourcefn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
fn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
impl IsObjectType for RbumSetDetailResp
Sourceimpl ParseFromJSON for RbumSetDetailResp
impl ParseFromJSON for RbumSetDetailResp
Sourcefn parse_from_json(value: Option<Value>) -> Result<Self, ParseError<Self>>
fn parse_from_json(value: Option<Value>) -> Result<Self, ParseError<Self>>
Parse from
serde_json::Value.Sourcefn parse_from_json_string(s: &str) -> Result<Self, ParseError<Self>>
fn parse_from_json_string(s: &str) -> Result<Self, ParseError<Self>>
Parse from JSON string.
Sourceimpl ParseFromXML for RbumSetDetailResp
impl ParseFromXML for RbumSetDetailResp
Sourcefn parse_from_xml(value: Option<Value>) -> Result<Self, ParseError<Self>>
fn parse_from_xml(value: Option<Value>) -> Result<Self, ParseError<Self>>
Parse from
serde_json::Value.Sourcefn parse_from_xml_string(s: &str) -> Result<Self, ParseError<Self>>
fn parse_from_xml_string(s: &str) -> Result<Self, ParseError<Self>>
Parse from XML string.
Sourceimpl ParseFromYAML for RbumSetDetailResp
impl ParseFromYAML for RbumSetDetailResp
Sourcefn parse_from_yaml(value: Option<Value>) -> Result<Self, ParseError<Self>>
fn parse_from_yaml(value: Option<Value>) -> Result<Self, ParseError<Self>>
Parse from
serde_json::Value.Sourcefn parse_from_yaml_string(s: &str) -> Result<Self, ParseError<Self>>
fn parse_from_yaml_string(s: &str) -> Result<Self, ParseError<Self>>
Parse from YAML string.
Sourceimpl Serialize for RbumSetDetailResp
impl Serialize for RbumSetDetailResp
Sourceimpl ToJSON for RbumSetDetailResp
impl ToJSON for RbumSetDetailResp
Sourceimpl ToXML for RbumSetDetailResp
impl ToXML for RbumSetDetailResp
Sourceimpl ToYAML for RbumSetDetailResp
impl ToYAML for RbumSetDetailResp
Sourceimpl Type for RbumSetDetailResp
impl Type for RbumSetDetailResp
Sourceconst IS_REQUIRED: bool = true
const IS_REQUIRED: bool = true
If it is
true, it means that this type is required.Sourcetype RawValueType = RbumSetDetailResp
type RawValueType = RbumSetDetailResp
The raw type used for validator. Read more
Sourcetype RawElementValueType = RbumSetDetailResp
type RawElementValueType = RbumSetDetailResp
The raw element type used for validator.
Sourcefn schema_ref() -> MetaSchemaRef
fn schema_ref() -> MetaSchemaRef
Get schema reference of this type.
Sourcefn as_raw_value(&self) -> Option<&Self::RawValueType>
fn as_raw_value(&self) -> Option<&Self::RawValueType>
Returns a reference to the raw value.
Sourcefn raw_element_iter<'a>(
&'a self,
) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a>
fn raw_element_iter<'a>( &'a self, ) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a>
Returns an iterator for traversing the elements.