pub struct RbumSetSummaryResp {}Expand description
Resource set summary information
资源集概要信息
Fields
id: StringResource set id
资源集id
code: StringResource set code
资源集编码
kind: StringResource set kind
资源集类型
name: StringResource set name
资源集名称
icon: StringResource set icon
资源集图标
sort: i64Resource set sort
资源集排序
ext: StringResource set extension information
资源集扩展信息
own_paths: Stringowner: Stringcreate_time: DateTime<Utc>update_time: DateTime<Utc>scope_level: RbumScopeLevelKinddisabled: boolTrait Implementations
Sourceimpl Debug for RbumSetSummaryResp
impl Debug for RbumSetSummaryResp
Sourceimpl<'de> Deserialize<'de> for RbumSetSummaryResp
impl<'de> Deserialize<'de> for RbumSetSummaryResp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromQueryResult for RbumSetSummaryResp
impl FromQueryResult for RbumSetSummaryResp
Sourcefn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
fn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
Instantiate a Model from a QueryResult Read more
Sourcefn from_query_result_nullable(
row: &QueryResult,
pre: &str,
) -> Result<Self, TryGetError>
fn from_query_result_nullable( row: &QueryResult, pre: &str, ) -> Result<Self, TryGetError>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option Read more
Sourcefn from_query_result_optional(
res: &QueryResult,
pre: &str,
) -> Result<Option<Self>, DbErr>
fn from_query_result_optional( res: &QueryResult, pre: &str, ) -> Result<Option<Self>, DbErr>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option
Sourcefn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
fn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
impl IsObjectType for RbumSetSummaryResp
Sourceimpl ParseFromJSON for RbumSetSummaryResp
impl ParseFromJSON for RbumSetSummaryResp
Sourcefn parse_from_json(value: Option<Value>) -> Result<Self, ParseError<Self>>
fn parse_from_json(value: Option<Value>) -> Result<Self, ParseError<Self>>
Parse from
serde_json::Value.Sourcefn parse_from_json_string(s: &str) -> Result<Self, ParseError<Self>>
fn parse_from_json_string(s: &str) -> Result<Self, ParseError<Self>>
Parse from JSON string.
Sourceimpl ParseFromXML for RbumSetSummaryResp
impl ParseFromXML for RbumSetSummaryResp
Sourcefn parse_from_xml(value: Option<Value>) -> Result<Self, ParseError<Self>>
fn parse_from_xml(value: Option<Value>) -> Result<Self, ParseError<Self>>
Parse from
serde_json::Value.Sourcefn parse_from_xml_string(s: &str) -> Result<Self, ParseError<Self>>
fn parse_from_xml_string(s: &str) -> Result<Self, ParseError<Self>>
Parse from XML string.
Sourceimpl ParseFromYAML for RbumSetSummaryResp
impl ParseFromYAML for RbumSetSummaryResp
Sourcefn parse_from_yaml(value: Option<Value>) -> Result<Self, ParseError<Self>>
fn parse_from_yaml(value: Option<Value>) -> Result<Self, ParseError<Self>>
Parse from
serde_json::Value.Sourcefn parse_from_yaml_string(s: &str) -> Result<Self, ParseError<Self>>
fn parse_from_yaml_string(s: &str) -> Result<Self, ParseError<Self>>
Parse from YAML string.
Sourceimpl Serialize for RbumSetSummaryResp
impl Serialize for RbumSetSummaryResp
Sourceimpl ToJSON for RbumSetSummaryResp
impl ToJSON for RbumSetSummaryResp
Sourceimpl ToXML for RbumSetSummaryResp
impl ToXML for RbumSetSummaryResp
Sourceimpl ToYAML for RbumSetSummaryResp
impl ToYAML for RbumSetSummaryResp
Sourceimpl Type for RbumSetSummaryResp
impl Type for RbumSetSummaryResp
Sourceconst IS_REQUIRED: bool = true
const IS_REQUIRED: bool = true
If it is
true, it means that this type is required.Sourcetype RawValueType = RbumSetSummaryResp
type RawValueType = RbumSetSummaryResp
The raw type used for validator. Read more
Sourcetype RawElementValueType = RbumSetSummaryResp
type RawElementValueType = RbumSetSummaryResp
The raw element type used for validator.
Sourcefn schema_ref() -> MetaSchemaRef
fn schema_ref() -> MetaSchemaRef
Get schema reference of this type.
Sourcefn as_raw_value(&self) -> Option<&Self::RawValueType>
fn as_raw_value(&self) -> Option<&Self::RawValueType>
Returns a reference to the raw value.
Sourcefn raw_element_iter<'a>(
&'a self,
) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a>
fn raw_element_iter<'a>( &'a self, ) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a>
Returns an iterator for traversing the elements.