pub struct RbumConfig {
pub set_cate_sys_code_node_len: usize,
pub mq_topic_entity_deleted: String,
pub mq_topic_event: String,
pub mq_header_name_operator: String,
pub task_mq_topic_event: String,
pub cache_key_set_code_: String,
pub cache_key_set_code_expire_sec: usize,
pub cache_key_cert_vcode_info_: String,
pub cache_key_cert_locked_: String,
pub cache_key_cert_err_times_: String,
pub event_domains: HashMap<String, String>,
pub head_key_bios_ctx: String,
}Expand description
Rbum configuration
Rbum 配置
Fields
set_cate_sys_code_node_len: usizeThe length of the system code of the set category(node)
集合分类(节点)系统代码的长度
mq_topic_entity_deleted: StringThe topic of the message queue when the entity is deleted
实体删除时的消息队列主题
TODO
mq_topic_event: StringThe topic of the message queue when the event occurs
事件发生时的消息队列主题
mq_header_name_operator: Stringtask_mq_topic_event: Stringcache_key_set_code_: StringCache key prefix for resource set code
资源集合代码的缓存键前缀
Format: set_code -> set_id
cache_key_set_code_expire_sec: usizeCache key expiration time for resource set code
资源集合代码的缓存键过期时间
cache_key_cert_vcode_info_: StringCache key prefix for certificate verification code information
凭证验证码信息的缓存键前缀
Format: own_paths:ak -> vcode
cache_key_cert_locked_: StringCache key prefix for locked certificate
锁定凭证的缓存键前缀
Format: rbum_item_id -> nil
cache_key_cert_err_times_: StringCache key prefix for certificate error times
凭证错误次数的缓存键前缀
Format: rbum_item_id -> error times by cycle
event_domains: HashMap<String, String>Event domain configuration
事件域配置
Format: table name (supports prefix matching) -> <c><u><d>
TODO
head_key_bios_ctx: StringHeader name of BIOS context request
BIOS 上下文的请求头名称