pub struct RbumItemKernelAddReq {
pub id: Option<TrimString>,
pub code: Option<TrimString>,
pub name: TrimString,
pub rel_rbum_kind_id: Option<String>,
pub rel_rbum_domain_id: Option<String>,
pub scope_level: Option<RbumScopeLevelKind>,
pub disabled: Option<bool>,
}Expand description
Add request for resource item kernel
资源项内核添加请求
Different from crate::rbum::dto::rbum_item_dto::RbumItemAddReq, this object is used when there is a resource item extension table,
and the resource item contains kernel information (the rbum_item table) and extension information (the corresponding extension table).
与 crate::rbum::dto::rbum_item_dto::RbumItemAddReq 不同,此对象用于有资源项扩展表的情况下使用,此时资源项包含了内核信息(rbum_item表)和扩展信息(对应的扩展表)。
Fields
id: Option<TrimString>Resource item id
资源项id
code: Option<TrimString>Resource item code
资源项编码
name: TrimStringResource item name
资源项名称
rel_rbum_kind_id: Option<String>Associated resource kind id
关联的资源类型 id
Special kind can be set, otherwise the default kind will be used. Note that setting special kind must ensure that the permissions are correct.
可以设置特殊的类型,否则将使用默认类型。 注意设置特殊类型必须确保权限正确。
rel_rbum_domain_id: Option<String>Associated resource domain id
关联的资源域 id
Special domain can be set, otherwise the default domain will be used. Note that setting special domain must ensure that the permissions are correct.
可以设置特殊的域,否则将使用默认域。 注意设置特殊域必须确保权限正确。
scope_level: Option<RbumScopeLevelKind>disabled: Option<bool>Trait Implementations
Sourceimpl Debug for RbumItemKernelAddReq
impl Debug for RbumItemKernelAddReq
Sourceimpl Default for RbumItemKernelAddReq
impl Default for RbumItemKernelAddReq
Sourceimpl<'de> Deserialize<'de> for RbumItemKernelAddReqwhere
RbumItemKernelAddReq: Default,
impl<'de> Deserialize<'de> for RbumItemKernelAddReqwhere
RbumItemKernelAddReq: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,