pub struct RbumKindModifyReq {
pub module: Option<String>,
pub name: Option<TrimString>,
pub note: Option<String>,
pub icon: Option<String>,
pub sort: Option<i64>,
pub ext_table_name: Option<String>,
pub scope_level: Option<RbumScopeLevelKind>,
}Expand description
Modify request for resource kind
资源类型修改请求
Fields
module: Option<String>Resource kind module
资源类型模块
Used to further divide the resource kind. For example, there are multiple resource kinds under the cmdb compute module, such as ecs, ec2, k8s.
用于对资源类型做简单的分类。比如 cmdb计算 模块下可以有 ecs、ec2、k8s 等多个资源类型。
name: Option<TrimString>Resource kind name
资源类型名称
note: Option<String>Resource kind note
资源类型备注
icon: Option<String>Resource kind icon
资源类型图标
sort: Option<i64>Resource kind sort
资源类型排序
ext_table_name: Option<String>Extension table name
扩展表名
Each resource kind can specify an extension table for storing customized data.
每个资源类型可以指定一个扩展表用于存储自定义数据。
scope_level: Option<RbumScopeLevelKind>Trait Implementations
Sourceimpl Debug for RbumKindModifyReq
impl Debug for RbumKindModifyReq
Sourceimpl<'de> Deserialize<'de> for RbumKindModifyReq
impl<'de> Deserialize<'de> for RbumKindModifyReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl IsObjectType for RbumKindModifyReq
Sourceimpl ParseFromJSON for RbumKindModifyReq
impl ParseFromJSON for RbumKindModifyReq
Sourcefn parse_from_json(value: Option<Value>) -> Result<Self, ParseError<Self>>
fn parse_from_json(value: Option<Value>) -> Result<Self, ParseError<Self>>
Parse from
serde_json::Value.Sourcefn parse_from_json_string(s: &str) -> Result<Self, ParseError<Self>>
fn parse_from_json_string(s: &str) -> Result<Self, ParseError<Self>>
Parse from JSON string.
Sourceimpl ParseFromXML for RbumKindModifyReq
impl ParseFromXML for RbumKindModifyReq
Sourcefn parse_from_xml(value: Option<Value>) -> Result<Self, ParseError<Self>>
fn parse_from_xml(value: Option<Value>) -> Result<Self, ParseError<Self>>
Parse from
serde_json::Value.Sourcefn parse_from_xml_string(s: &str) -> Result<Self, ParseError<Self>>
fn parse_from_xml_string(s: &str) -> Result<Self, ParseError<Self>>
Parse from XML string.
Sourceimpl ParseFromYAML for RbumKindModifyReq
impl ParseFromYAML for RbumKindModifyReq
Sourcefn parse_from_yaml(value: Option<Value>) -> Result<Self, ParseError<Self>>
fn parse_from_yaml(value: Option<Value>) -> Result<Self, ParseError<Self>>
Parse from
serde_json::Value.Sourcefn parse_from_yaml_string(s: &str) -> Result<Self, ParseError<Self>>
fn parse_from_yaml_string(s: &str) -> Result<Self, ParseError<Self>>
Parse from YAML string.
Sourceimpl Serialize for RbumKindModifyReq
impl Serialize for RbumKindModifyReq
Sourceimpl ToJSON for RbumKindModifyReq
impl ToJSON for RbumKindModifyReq
Sourceimpl ToXML for RbumKindModifyReq
impl ToXML for RbumKindModifyReq
Sourceimpl ToYAML for RbumKindModifyReq
impl ToYAML for RbumKindModifyReq
Sourceimpl Type for RbumKindModifyReq
impl Type for RbumKindModifyReq
Sourceconst IS_REQUIRED: bool = true
const IS_REQUIRED: bool = true
If it is
true, it means that this type is required.Sourcetype RawValueType = RbumKindModifyReq
type RawValueType = RbumKindModifyReq
The raw type used for validator. Read more
Sourcetype RawElementValueType = RbumKindModifyReq
type RawElementValueType = RbumKindModifyReq
The raw element type used for validator.
Sourcefn schema_ref() -> MetaSchemaRef
fn schema_ref() -> MetaSchemaRef
Get schema reference of this type.
Sourcefn as_raw_value(&self) -> Option<&Self::RawValueType>
fn as_raw_value(&self) -> Option<&Self::RawValueType>
Returns a reference to the raw value.
Sourcefn raw_element_iter<'a>(
&'a self,
) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a>
fn raw_element_iter<'a>( &'a self, ) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a>
Returns an iterator for traversing the elements.